@@ -29,6 +29,6 @@ fn main() {
        if pos.x >= 0.0 { "positive" } else { "negative" },
        if pos.y >= 0.0 { "positive" } else { "negative" });
 
-    valv!(pos);
+    valf!(pos);
 }
 
