@@ -9,5 +9,5 @@ fn main() {
     info!("{:?}", v1);
     val!(v1, n, v2);
     valn!(v1, v2, v3);
-    valv!(v1, n, v2, v3);
+    valf!(v1, n, v2, v3);
 }
\ No newline at end of file
